pub(crate) struct Arguments {
pub(crate) url: Vec<String>,
pub(crate) token: Option<String>,
pub(crate) labels: Vec<String>,
pub(crate) validation_details: bool,
pub(crate) validation_max_hours: u16,
pub(crate) command: Option<Command>,
}Fields
url: Vec<String>The URLs of the GitLab repositories you want to export time logs from. When using multiple URLs, separate them with a space.
token: Option<String>A GitLab access token. Needed if the repository is not public. Can be a personal, group, or repository access token. All repositories must be accessible with the same token, using different tokens per repository is not supported.
labels: Vec<String>Comma-separated list of GitLab labels to filter by. All other labels will be grouped under
“Others”. If your labels contain spaces, delimit them with ":
--labels "Epic 1",Documentation. The labels are case-sensitive.
If not set, all labels are shown.
validation_details: boolDisplays the problems with the time logs found during validation.
validation_max_hours: u16When validating time logs, the maximum number of hours a time log should have.
command: Option<Command>The subcommand to run.